==> elrond-wasm-0.22.9.crate: elrond-wasm-0.22.9/src/api/uncallable/blockchain_api_uncallable.rs <==
use alloc::boxed::Box;

use crate::{
    api::BlockchainApi,
    types::{Address, BigUint, EsdtTokenData, ManagedAddress, TokenIdentifier, H256},
};

use super::UncallableApi;

impl BlockchainApi for UncallableApi {
    fn get_sc_address_legacy(&self) -> Address {
        unreachable!()
    }

    fn get_owner_address_legacy(&self) -> Address {
        unreachable!()
    }

    fn get_shard_of_address_legacy(&self, _address: &Address) -> u32 {
        unreachable!()
    }

    fn is_smart_contract_legacy(&self, _address: &Address) -> bool {
        unreachable!()
    }

    fn get_caller_legacy(&self) -> Address {
        unreachable!()
    }

    fn get_balance_legacy(&self, _address: &Address) -> BigUint<Self> {
        unreachable!()
    }

    fn get_state_root_hash_legacy(&self) -> H256 {
        unreachable!()
    }

    fn get_tx_hash_legacy(&self) -> H256 {
        unreachable!()
    }

    fn get_gas_left(&self) -> u64 {
        unreachable!()
    }

    fn get_block_timestamp(&self) -> u64 {
        unreachable!()
    }

    fn get_block_nonce(&self) -> u64 {
        unreachable!()
    }

    fn get_block_round(&self) -> u64 {
        unreachable!()
    }

    fn get_block_epoch(&self) -> u64 {
        unreachable!()
    }

    fn get_block_random_seed_legacy(&self) -> Box<[u8; 48]> {
        unreachable!()
    }

    fn get_prev_block_timestamp(&self) -> u64 {
        unreachable!()
    }

    fn get_prev_block_nonce(&self) -> u64 {
        unreachable!()
    }

    fn get_prev_block_round(&self) -> u64 {
        unreachable!()
    }

    fn get_prev_block_epoch(&self) -> u64 {
        unreachable!()
    }

    fn get_prev_block_random_seed_legacy(&self) -> Box<[u8; 48]> {
        unreachable!()
    }

    fn get_current_esdt_nft_nonce(
        &self,
        _address: &ManagedAddress<Self>,
        _token: &TokenIdentifier<Self>,
    ) -> u64 {
        unreachable!()
    }

    // TODO: Include nonce and create a map like: TokenId -> Nonce -> Amount
    fn get_esdt_balance(
        &self,
        _address: &ManagedAddress<Self>,
        _token: &TokenIdentifier<Self>,
        _nonce: u64,
    ) -> BigUint<Self> {
        unreachable!()
    }

    fn get_esdt_token_data(
        &self,
        _address: &ManagedAddress<Self>,
        _token: &TokenIdentifier<Self>,
        _nonce: u64,
    ) -> EsdtTokenData<Self> {
        unreachable!()
    }
}

==> elrond-wasm-0.27.2.crate: elrond-wasm-0.27.2/src/api/uncallable/blockchain_api_uncallable.rs <==
use alloc::boxed::Box;

use crate::{
    api::{BlockchainApi, BlockchainApiImpl, Handle, ManagedTypeApi},
    types::{Address, BigUint, EsdtTokenData, ManagedAddress, TokenIdentifier, H256},
};

use super::UncallableApi;

impl BlockchainApi for UncallableApi {
    type BlockchainApiImpl = UncallableApi;

    fn blockchain_api_impl() -> Self::BlockchainApiImpl {
        unreachable!()
    }
}

impl BlockchainApiImpl for UncallableApi {
    fn get_sc_address_legacy(&self) -> Address {
        unreachable!()
    }

    fn get_owner_address_legacy(&self) -> Address {
        unreachable!()
    }

    fn get_shard_of_address_legacy(&self, _address: &Address) -> u32 {
        unreachable!()
    }

    fn is_smart_contract_legacy(&self, _address: &Address) -> bool {
        unreachable!()
    }

    fn get_caller_legacy(&self) -> Address {
        unreachable!()
    }

    fn get_balance_legacy(&self, _address: &Address) -> Handle {
        unreachable!()
    }

    fn get_state_root_hash_legacy(&self) -> H256 {
        unreachable!()
    }

    fn get_tx_hash_legacy(&self) -> H256 {
        unreachable!()
    }

    fn get_gas_left(&self) -> u64 {
        unreachable!()
    }

    fn get_block_timestamp(&self) -> u64 {
        unreachable!()
    }

    fn get_block_nonce(&self) -> u64 {
        unreachable!()
    }

    fn get_block_round(&self) -> u64 {
        unreachable!()
    }

    fn get_block_epoch(&self) -> u64 {
        unreachable!()
    }

    fn get_block_random_seed_legacy(&self) -> Box<[u8; 48]> {
        unreachable!()
    }

    fn get_prev_block_timestamp(&self) -> u64 {
        unreachable!()
    }

    fn get_prev_block_nonce(&self) -> u64 {
        unreachable!()
    }

    fn get_prev_block_round(&self) -> u64 {
        unreachable!()
    }

    fn get_prev_block_epoch(&self) -> u64 {
        unreachable!()
    }

    fn get_prev_block_random_seed_legacy(&self) -> Box<[u8; 48]> {
        unreachable!()
    }

    fn get_current_esdt_nft_nonce<M: ManagedTypeApi>(
        &self,
        _address: &ManagedAddress<M>,
        _token: &TokenIdentifier<M>,
    ) -> u64 {
        unreachable!()
    }

    fn get_esdt_balance<M: ManagedTypeApi>(
        &self,
        _address: &ManagedAddress<M>,
        _token: &TokenIdentifier<M>,
        _nonce: u64,
    ) -> BigUint<M> {
        unreachable!()
    }

    fn get_esdt_token_data<M: ManagedTypeApi>(
        &self,
        _address: &ManagedAddress<M>,
        _token: &TokenIdentifier<M>,
        _nonce: u64,
    ) -> EsdtTokenData<M> {
        unreachable!()
    }

    fn get_esdt_local_roles<M: ManagedTypeApi>(
        &self,
        _token_id: &TokenIdentifier<M>,
    ) -> crate::types::EsdtLocalRoleFlags {
        unreachable!()
    }
}
